@@ -1,3 +1,5 @@
+require 'tins/xt/full'
+
 module Term
 
   # The ANSIColor module can be used for namespacing and mixed into your own
@@ -6,6 +8,7 @@ module Term
     require 'term/ansicolor/version'
     require 'term/ansicolor/attribute'
     require 'term/ansicolor/rgb_triple'
+    require 'term/ansicolor/hsl_triple'
     require 'term/ansicolor/ppm_reader'
     require 'term/ansicolor/attribute/text'
     require 'term/ansicolor/attribute/color8'
@@ -83,7 +86,7 @@ module Term
       result = ''
       result << "\e[#{attribute.code}m" if Term::ANSIColor.coloring?
       if block_given?
-        result << yield
+        result << yield.to_s
       elsif string.respond_to?(:to_str)
         result << string.to_str
       elsif respond_to?(:to_str)
